From c950e3b3f919c94a5356e69ccff8ac3072e56b7f Mon Sep 17 00:00:00 2001
From: Chen Qun <kuhn.chenqun@huawei.com>
Date: Wed, 8 Apr 2020 14:21:04 +0800
Subject: [PATCH 02/16] numa_opts: uses smp_override instead of vcpu_maxcpus
 for aarch64

It will create vm failed, if only add 'vcpu_maxcpus'.
We delete it, and uses 'smp_override' and 'mem_override' params.

Signed-off-by: Chen Qun <kuhn.chenqun@huawei.com>
---
 qemu/tests/cfg/numa_opts.cfg | 17 +++++++++--------
 qemu/tests/numa_opts.py      |  3 +++
 2 files changed, 12 insertions(+), 8 deletions(-)

diff --git a/qemu/tests/cfg/numa_opts.cfg b/qemu/tests/cfg/numa_opts.cfg
index f19ee16a..29d14d26 100644
--- a/qemu/tests/cfg/numa_opts.cfg
+++ b/qemu/tests/cfg/numa_opts.cfg
@@ -1,14 +1,15 @@
 - numa_opts:
   type = numa_opts
+  # manually override the "mem" parameter before starting it
+  start_vm = no
   # paused VMs are enough for our purposes, no need to boot them:
   paused_after_start_vm = yes
   kill_vm = yes
   kill_vm_gracefully = no
   encode_video_files = no
   pre_command = "sync && echo 3 >/proc/sys/vm/drop_caches;"
-  smp = 6
-  mem = 4096
-  vcpu_maxcpus = ${smp}
+  smp_override = 6
+  mem_override = 4096
   variants:
     - nodes.0:
       # no extra parameters => zero nodes
@@ -27,8 +28,8 @@
         # default (interleaved) mode:
         - defaults:
           extra_params += " -numa node -numa node"
-          numa_node0_cpus = "0 1 2"
-          numa_node1_cpus = "3 4 5"
+          numa_node0_cpus = "0 2 4"
+          numa_node1_cpus = "1 3 5"
           numa_node0_size = 2048
           numa_node1_size = 2048
           Host_RHEL.m6, Host_RHEL.m7.u0, Host_RHEL.m7.u1:
@@ -58,9 +59,9 @@
         - defaults:
           extra_params += " -numa node -numa node -numa node"
           # nodes are 8MB-aligned:
-          numa_node0_cpus = "0 1 2"
-          numa_node1_cpus = "3 4 5"
-          numa_node2_cpus = ""
+          numa_node0_cpus = "0 3"
+          numa_node1_cpus = "1 4"
+          numa_node2_cpus = "2 5"
           numa_node0_size = 1360
           numa_node1_size = 1368
           numa_node2_size = 1368
diff --git a/qemu/tests/numa_opts.py b/qemu/tests/numa_opts.py
index 3a1d489c..016fd092 100644
--- a/qemu/tests/numa_opts.py
+++ b/qemu/tests/numa_opts.py
@@ -15,7 +15,10 @@ def run(test, params, env):
 
     dbg("starting numa_opts test...")
 
+    params["smp"] = params.get("smp_override")
+    params["mem"] = params.get("mem_override")
     vm = env.get_vm(params["main_vm"])
+    vm.create(params=params)
 
     numa = vm.monitors[0].info_numa()
     dbg("info numa reply: %r", numa)
-- 
2.23.0

